@@ -303,8 +303,8 @@ def send_msg(from_addr: str,
         try:
             session.login(user, password)
         except smtplib.SMTPException as e:
-            raise RuntimeError("send_msg: Failed to login as user {}: {}".format(
-                user, e))
+            raise RuntimeError(
+                "send_msg: Failed to login as user {}: {}".format(user, e))
     else:
         log.debug("Not using SMTP AUTH; no user specified")
         # For systems with... lax... security requirements
@@ -470,7 +470,7 @@ def send_email(from_addr: str,
 # Misc
 # =============================================================================
 
-_SIMPLE_EMAIL_REGEX = re.compile("[^@]+@[^@]+\.[^@]+")
+_SIMPLE_EMAIL_REGEX = re.compile(r"[^@]+@[^@]+\.[^@]+")
 
 
 def is_email_valid(email_: str) -> bool:
